@@ -40,8 +40,6 @@
 
 Q_DECL_EXPORT int main(int argc, char *argv[])
 {
-    QGuiApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
-    QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
     QGuiApplication::setApplicationDisplayName(QStringLiteral("Kirigami Gallery"));
     QGuiApplication::setDesktopFileName(QStringLiteral("org.kde.kirigami2.gallery"));
 
